1. Line plot
2. Skew feature]
3. show_distribution
4. plot_scatter
5. plot_correlation
6. histogram (3)
plot bar
boxplot
7. datasetShape
8. diagnostic_plots
9. divideFeatures
10. fillNan
11. get_correlation
12. plot_cont_kde
13. best fit [not sure]
14. calculating_missing_values


Visua





Instructions:
1. Test > codes that I wanted to use a library 
2. Test> test> scripts
3. init.py te sob import kore rakhte hobe
4. structure organize kora
5. 

test.remove_outlier()





REf: https://notebook.community/mzohaib10/datascience-starters/visualization-in-matplotlib/visualization-in-matplotlib